﻿/**
 * @file
 * Vuo prefix header.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This interface description may be modified and distributed under the terms of the GNU Lesser General Public License (LGPL) version 2 or later.
 * For more information, see http://vuo.org/license.
 */

#ifndef VUO_H
#define VUO_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wdocumentation"
#include <json/json.h>
#pragma clang diagnostic pop

#include <zmq/zmq.h>

#ifdef __cplusplus

#include <string>
#include <vector>
#include <map>
#include <list>

using namespace std;

#define __STDC_CONSTANT_MACROS
#define __STDC_FORMAT_MACROS
#define __STDC_LIMIT_MACROS

#ifdef NO
	#define VUO_NO_ALREADY_DEFINED
	#undef NO
#endif
#define NO VUO_LLVM_NO_RENAMED

#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wunused-parameter"
#pragma clang diagnostic ignored "-Wunused-private-field"
#pragma clang diagnostic ignored "-Wshorten-64-to-32"
#include <clang/Basic/Version.h>
#include <clang/CodeGen/CodeGenAction.h>
#include <clang/Driver/ArgList.h>
#include <clang/Driver/Compilation.h>
#include <clang/Driver/Driver.h>
#include <clang/Driver/ToolChain.h>
#include <clang/Frontend/CompilerInstance.h>
#include <clang/Frontend/CompilerInvocation.h>
#include <clang/Frontend/FrontendDiagnostic.h>
#include <clang/Frontend/TextDiagnosticPrinter.h>
#include <llvm/Support/DynamicLibrary.h>
#include <llvm/Support/Host.h>
#include <llvm/Support/Program.h>
#include <llvm/Bitcode/Archive.h>
#include <llvm/LLVMContext.h>
#include <llvm/Module.h>
#include <llvm/DerivedTypes.h>
#include <llvm/Constants.h>
#include <llvm/Instructions.h>
#include <llvm/LinkAllPasses.h>
#include <llvm/Linker.h>
#include <llvm/PassManager.h>
#include <llvm/Analysis/Verifier.h>
#include <llvm/Analysis/ValueTracking.h>
#include <llvm/Bitcode/ReaderWriter.h>
#include <llvm/ExecutionEngine/JIT.h>
#include <llvm/ExecutionEngine/Interpreter.h>
#include <llvm/ExecutionEngine/GenericValue.h>
#include <llvm/Support/raw_ostream.h>
#include <llvm/Support/MemoryBuffer.h>
#include <llvm/Support/system_error.h>
#include <llvm/Support/IRReader.h>
#include <llvm/Support/PathV1.h>
#include <llvm/Support/TargetSelect.h>
#include <llvm/Transforms/Utils/Cloning.h>
#include <llvm/ValueSymbolTable.h>
#pragma clang diagnostic pop

#undef NO
#ifdef VUO_NO_ALREADY_DEFINED
	#undef VUO_NO_ALREADY_DEFINED
	// From /usr/include/objc/objc.h line 58
	#define NO __objc_no
#endif

using namespace llvm;

#include "VuoBase.hh"
#include "VuoBaseDetail.hh"
#include "VuoNodeClass.hh"
#include "VuoNode.hh"
#include "VuoNodeSet.hh"
#include "VuoPort.hh"
#include "VuoPortClass.hh"
#include "VuoCable.hh"
#include "VuoRunner.hh"
#include "VuoFileUtilities.hh"
#include "VuoStringUtilities.hh"
#include "VuoPublishedPort.hh"
#include "VuoModule.hh"
#include "VuoType.hh"
#include "VuoGenericType.hh"
#include "VuoTimeUtilities.hh"
#include "VuoComposition.hh"
#include "VuoCompilerPassiveEdge.hh"
#include "VuoCompilerPortClass.hh"
#include "VuoCompilerPort.hh"
#include "VuoCompilerDataClass.hh"
#include "VuoCompilerData.hh"
#include "VuoCompilerOutputDataClass.hh"
#include "VuoCompilerOutputData.hh"
#include "VuoCompilerEventPortClass.hh"
#include "VuoCompilerEventPort.hh"
#include "VuoCompilerOutputEventPortClass.hh"
#include "VuoCompilerOutputEventPort.hh"
#include "VuoCompilerNodeClass.hh"
#include "VuoCompilerNodeArgumentClass.hh"
#include "VuoCompilerNodeArgument.hh"
#include "VuoCompilerNode.hh"
#include "VuoCompilerLeaf.hh"
#include "VuoCompilerInstanceDataClass.hh"
#include "VuoCompilerInstanceData.hh"
#include "VuoCompilerInputDataClass.hh"
#include "VuoCompilerInputData.hh"
#include "VuoCompilerInputEventPortClass.hh"
#include "VuoCompilerInputEventPort.hh"
#include "VuoCompilerGraphvizParser.hh"
#include "VuoCompilerBitcodeGenerator.hh"
#include "VuoCompilerTriggerPortClass.hh"
#include "VuoCompilerTriggerPort.hh"
#include "VuoCompilerTriggerEdge.hh"
#include "VuoCompilerTriggerAction.hh"
#include "VuoCompilerEdge.hh"
#include "VuoCompilerDebug.hh"
#include "VuoCompilerChain.hh"
#include "VuoCompilerBitcodeParser.hh"
#include "VuoCompiler.hh"
#include "VuoCompilerCable.hh"
#include "VuoCompilerPublishedPort.hh"
#include "VuoCompilerPublishedInputPort.hh"
#include "VuoCompilerPublishedOutputPort.hh"
#include "VuoCompilerCodeGenUtilities.hh"
#include "VuoCompilerModule.hh"
#include "VuoCompilerType.hh"
#include "VuoCompilerGenericType.hh"
#include "VuoCompilerComposition.hh"
#include "VuoCompilerMakeListNodeClass.hh"
#include "VuoCompilerPublishedInputNodeClass.hh"
#include "VuoCompilerSpecializedNodeClass.hh"
#include "VuoCompilerTargetSet.hh"


#endif

#ifdef __cplusplus
extern "C"
{
#endif

#include "VuoTelemetry.h"
#include "miniz.h"
#include "VuoDisplayRefresh.h"
#include "VuoGlContext.h"
#include "VuoGlPool.h"
#include "VuoImageGet.h"
#include "VuoImageRenderer.h"
#include "VuoSceneRenderer.h"
#include "VuoUrl.h"
#include "VuoVerticesParametric.h"
#include "VuoWindow.h"
#include "VuoNSRunLoop.h"
#include "module.h"
#include "node.h"
#include "VuoThresholdType.h"
#include "VuoLeapFrame.h"
#include "VuoLeapHand.h"
#include "VuoLeapPointable.h"
#include "VuoLeapPointableType.h"
#include "VuoLeapTouchZone.h"
#include "VuoCurve.h"
#include "VuoCurveDomain.h"
#include "VuoWave.h"
#include "VuoMidiController.h"
#include "VuoMidiDevice.h"
#include "VuoMidiNote.h"
#include "VuoGradientNoise.h"
#include "VuoNoise.h"
#include "VuoSyphonServerDescription.h"
#include "VuoHeap.h"
#include "VuoRuntime.h"
#include "VuoBoolean.h"
#include "VuoBlendMode.h"
#include "VuoColor.h"
#include "VuoInteger.h"
#include "VuoImage.h"
#include "VuoImageWrapMode.h"
#include "VuoPoint2d.h"
#include "VuoPoint3d.h"
#include "VuoPoint4d.h"
#include "VuoReal.h"
#include "VuoSceneObject.h"
#include "VuoVertices.h"
#include "VuoShader.h"
#include "VuoSizingMode.h"
#include "VuoText.h"
#include "VuoTransform.h"
#include "VuoTransform2d.h"
#include "VuoWindowReference.h"
#include "VuoWrapMode.h"
#include "type.h"
#include "VuoGlContext.h"
#include "VuoGlPool.h"


#ifdef __cplusplus
}
#endif

#endif
