/**
 * @file
 * VuoList_VuoTransform C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoTransform_H
#define VuoList_VuoTransform_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoTransform VuoList_VuoTransform
 * A list of @ref VuoTransform elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoTransform
 * A list of @ref VuoTransform elements.
 */
#ifndef VuoList_VuoTransform_TYPE_DEFINED
typedef void * VuoList_VuoTransform;
#endif

/**
 * Creates a new list of @ref VuoTransform elements.
 */
VuoList_VuoTransform VuoListCreate_VuoTransform(void);

/**
 * Returns the @ref VuoTransform at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoTransform VuoListGetValueAtIndex_VuoTransform(const VuoList_VuoTransform list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoTransform(VuoList_VuoTransform list, const VuoTransform value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoTransform(VuoList_VuoTransform list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoTransform(VuoList_VuoTransform list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoTransform(const VuoList_VuoTransform list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoTransform VuoList_VuoTransform_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoTransform_jsonFromValue(const VuoList_VuoTransform value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoTransform_summaryFromValue(const VuoList_VuoTransform value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoTransform VuoList_VuoTransform_valueFromString(const char *str);
char * VuoList_VuoTransform_stringFromValue(const VuoList_VuoTransform value);
/// @}

/**
 * @}
 */

#endif
